16,209/18,393 built (88.1%) — 5,609 success, 10,600 failed
| Commit | Subject | Author | Status | Size | Duration | Date |
|---|---|---|---|---|---|---|
| c82a0cd2b | seedrng: shorten strings | SUCCESS | 1055 KB | 154s | 2022-04-27 | |
| 401356511 | seedrng: remove unnecessary zero-filling of local variables | SUCCESS | 1055 KB | 155s | 2022-04-27 | |
| 6da994735 | seedrng: remove unnecessary zero-filling of local variables | SUCCESS | 1055 KB | 154s | 2022-04-27 | |
| 137b20572 | seedrng: shrink --help text | SUCCESS | 1055 KB | 155s | 2022-04-27 | |
| 0cdd6f579 | libbb: fix fallout from nth_string() robustification, closes 14726 | SUCCESS | 1055 KB | 155s | 2022-04-27 | |
| 7fbfb2050 | kbuild: Prefer -Oz over -Os | SUCCESS | 1055 KB | 154s | 2022-04-24 | |
| 05c366a56 | seedrng: prune header includes | SUCCESS | 1055 KB | 155s | 2022-04-24 | |
| f9ea8ba5e | seedrng: code-golf even smaller | SUCCESS | 1055 KB | 154s | 2022-04-24 | |
| 831c754c9 | kbuild: fix building sha256 | SUCCESS | 1055 KB | 154s | 2022-04-21 | |
| c93eb1a95 | vi: fix backspace over tab in commands | SUCCESS | 1055 KB | 153s | 2022-04-20 | |
| 57fea029c | seedrng: compress format strings with %s arguments | SUCCESS | 1055 KB | 152s | 2022-04-20 | |
| 3c60711f8 | seedrng: remove some global variables | SUCCESS | 1055 KB | 154s | 2022-04-20 | |
| 398bb3861 | seedrng: further reduce size | SUCCESS | 1055 KB | 153s | 2022-04-20 | |
| ce9a34563 | seedrng: use predefined strings where possible | SUCCESS | 1055 KB | 153s | 2022-04-20 | |
| 3cb40f89d | seedrng: avoid needless runtime strlen() call | SUCCESS | 1055 KB | 153s | 2022-04-20 | |
| 31ec481ba | seedrng: hoist bb_strtoul out of min/max | SUCCESS | 1055 KB | 154s | 2022-04-20 | |
| 453857899 | seedrng: use libbb functions | SUCCESS | 1059 KB | 154s | 2022-04-20 | |
| 4b407bacd | seedrng: import SeedRNG utility for kernel RNG seed files | SUCCESS | 1059 KB | 154s | 2022-04-20 | |
| fc7868602 | vi: improved handling of backspace in replace mode | SUCCESS | 1055 KB | 153s | 2022-03-04 | |
| 55f969a00 | taskset: fix printf format mismatch in !FEATURE_TASKSET_FANCY config. closes 146 | SUCCESS | 1055 KB | 153s | 2022-03-01 | |
| 5fe20cf32 | ash: do not truncate failed tilde expansion on unknown user names | SUCCESS | 1055 KB | 154s | 2022-03-01 | |
| 7750b5a25 | ash: fix unsafe use of mempcpy | SUCCESS | 1055 KB | 153s | 2022-03-01 | |
| fa52ac978 | ash: don't read past end of var in subvareval for bash substitutions | SUCCESS | 1055 KB | 153s | 2022-03-01 | |
| 1891fdda5 | libbb/sha1: update config help text with new performance numbers | SUCCESS | 1055 KB | 152s | 2022-02-18 | |
| c2e7780e5 | libbb/sha256: explicitly use sha256rnds2's %xmm0 (MSG) argument | SUCCESS | 1055 KB | 155s | 2022-02-12 | |
| 1f272c06d | whitespace fixes | SUCCESS | 1055 KB | 152s | 2022-02-11 | |
| dda77e837 | libbb/sha1: revert last commit: pshufb is a SSSE3 insn, can't use it | SUCCESS | 1055 KB | 152s | 2022-02-11 | |
| 8154146be | libbb/sha1: shrink unrolled x86-64 code | SUCCESS | 1055 KB | 153s | 2022-02-11 | |
| 6f56fa171 | libbb/sha: improve comments | SUCCESS | 1055 KB | 153s | 2022-02-10 | |
| 6a6c1c0ea | whitespace fix | SUCCESS | 1055 KB | 154s | 2022-02-09 | |
| caa9c4f70 | libbb/sha256: code shrink in x86 assembly | SUCCESS | 1055 KB | 153s | 2022-02-09 | |
| 11bcea7ac | libbb/sha256: code shrink in 64-bit x86 | SUCCESS | 1055 KB | 154s | 2022-02-09 | |
| 461a994b0 | libbb/sha256: code shrink in 32-bit x86 | SUCCESS | 1055 KB | 153s | 2022-02-09 | |
| c0ff0d452 | libbb/sha256: code shrink in 32-bit x86 | SUCCESS | 1055 KB | 154s | 2022-02-09 | |
| eb8d5f3b8 | libbb/sha1: shrink x86 hardware accelerated hashing (32-bit) | SUCCESS | 1055 KB | 153s | 2022-02-08 | |
| eb52e7fa5 | libbb/sha1: shrink x86 hardware accelerated hashing (32-bit) | SUCCESS | 1055 KB | 154s | 2022-02-08 | |
| 71a1cccaa | libbb/sha1: shrink x86 hardware accelerated hashing | SUCCESS | 1055 KB | 154s | 2022-02-08 | |
| 4923f74e5 | libbb/sha1: shrink unrolled x86-64 code | SUCCESS | 1055 KB | 155s | 2022-02-08 | |
| c193cbd6d | libbb/sha1: shrink and speed up unrolled x86-64 code | SUCCESS | 1055 KB | 155s | 2022-02-07 | |
| 987be932e | *: slap on a few ALIGN_PTR where appropriate | SUCCESS | 1055 KB | 155s | 2022-02-06 | |
| ca466f385 | *: slap on a few ALIGN* where appropriate | SUCCESS | 1055 KB | 157s | 2022-02-06 | |
| 4f40735c8 | libbb/sha256: code shrink in 32-bit x86 | SUCCESS | 1055 KB | 158s | 2022-02-06 | |
| 31c1c3107 | libbb/sha256: code shrink in 64-bit x86 | SUCCESS | 1055 KB | 157s | 2022-02-06 | |
| a1429fbb8 | libbb/sha256: code shrink in 64-bit x86 | SUCCESS | 1055 KB | 157s | 2022-02-03 | |
| de6cb4bed | libbb/sha256: code shrink in 32-bit x86 | SUCCESS | 1055 KB | 156s | 2022-02-03 | |
| 6472ac942 | libbb/sha256: optional x86 hardware accelerated hashing | SUCCESS | 1055 KB | 155s | 2022-02-03 | |
| 205042c07 | libbb/sha1: in unrolled x86-64 code, pass initial W[] in registers, not on stack | SUCCESS | 1055 KB | 156s | 2022-01-25 | |
| 99e22d230 | cut: build fix for FEATURE_CUT_REGEX | SUCCESS | 1055 KB | 156s | 2022-01-24 | |
| 117a8c9b7 | apply const trick to ptr_to_globals | SUCCESS | 1055 KB | 156s | 2022-01-23 | |
| 78fdf4d22 | mkfs.vfat: fix volume label to be padded with space | SUCCESS | 1055 KB | 157s | 2022-01-23 |